@@ -2,7 +2,6 @@
 
 import re
 from .lazy_data import ld
-import jieba
 
 def is_regular_word(str1):
     if isinstance(str1, unicode): str1 = str1.encode("UTF-8")
@@ -12,4 +11,4 @@ def is_regular_word(str1):
 
 def jieba_parse(str1):
     """ 精确模式 """
-    return list(jieba.cut(str1, cut_all=False))
+    return list(ld.jieba.cut(str1, cut_all=False))
